@@ -1,7 +1,7 @@
 package Perinci::Examples::ArgsAs;
 
 our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.78'; # VERSION
+our $VERSION = '0.79'; # VERSION
 
 use 5.010001;
 use strict;
@@ -100,7 +100,7 @@ Perinci::Examples::ArgsAs - Demonstrate various values of `args_as` function met
 
 =head1 VERSION
 
-This document describes version 0.78 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2017-01-12.
+This document describes version 0.79 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2017-01-12.
 
 =head1 DESCRIPTION
 
@@ -218,7 +218,7 @@ Examples:
 
 =item * Without the optional arg3:
 
- args_as_hash(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg1", "abc", "arg2", 10], {}]
+ args_as_hash(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg2", 10, "arg1", "abc"], {}]
 
 =item * With the optional arg3:
 
@@ -226,7 +226,7 @@ Examples:
 
 Result:
 
- [200, "OK", ["arg3", 0.5, "arg2", 20, "arg1", "def"], {}]
+ [200, "OK", ["arg1", "def", "arg3", 0.5, "arg2", 20], {}]
 
 =back
 
@@ -309,7 +309,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
 
 =head1 BUGS
 
