@@ -1,7 +1,7 @@
 package Perinci::Examples::Tiny;
 
 our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.78'; # VERSION
+our $VERSION = '0.79'; # VERSION
 
 our %SPEC;
 
@@ -111,6 +111,53 @@ sub sum {
     [200, "OK", $sum];
 }
 
+$SPEC{noop2} = {
+    v => 1.1,
+    summary => "Just like noop, but accepts several arguments",
+    description => <<'_',
+
+Will return arguments passed to it.
+
+This function is also marked as `pure`, meaning it will not cause any side
+effects. Pure functions are safe to call directly in a transaction (without
+going through the transaction manager) or during dry-run mode.
+
+_
+    args => {
+        a => {
+            summary => 'Argument',
+            schema => ['any', {}, {}],
+            pos => 0,
+        },
+        b => {
+            summary => 'Argument',
+            schema => ['any', {}, {}],
+            pos => 1,
+        },
+        c => {
+            summary => 'Argument',
+            schema => ['any', {}, {}],
+            pos => 2,
+        },
+        d => {
+            summary => 'Argument',
+            schema => ['any', {}, {}],
+            pos => 3,
+        },
+        e => {
+            summary => 'Argument',
+            schema => ['any', {}, {}],
+            pos => 4,
+        },
+    },
+    features => {pure => 1},
+};
+
+sub noop2 {
+    my %args = @_;
+    [200, "OK", "a=$args{a}\nb=$args{b}\nc=$args{c}\nd=$args{d}\ne=$args{e}"];
+}
+
 1;
 # ABSTRACT: Small examples
 
@@ -126,7 +173,7 @@ Perinci::Examples::Tiny - Small examples
 
 =head1 VERSION
 
-This document describes version 0.78 of Perinci::Examples::Tiny (from Perl distribution Perinci-Examples), released on 2017-01-12.
+This document describes version 0.79 of Perinci::Examples::Tiny (from Perl distribution Perinci-Examples), released on 2017-01-12.
 
 =head1 DESCRIPTION
 
@@ -247,6 +294,59 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 noop2(%args) -> [status, msg, result, meta]
+
+Just like noop, but accepts several arguments.
+
+Will return arguments passed to it.
+
+This function is also marked as C<pure>, meaning it will not cause any side
+effects. Pure functions are safe to call directly in a transaction (without
+going through the transaction manager) or during dry-run mode.
+
+This function is not exported.
+
+This function is pure (produce no side effects).
+
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<a> => I<any>
+
+Argument.
+
+=item * B<b> => I<any>
+
+Argument.
+
+=item * B<c> => I<any>
+
+Argument.
+
+=item * B<d> => I<any>
+
+Argument.
+
+=item * B<e> => I<any>
+
+Argument.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 odd_even(%args) -> [status, msg, result, meta]
 
 Return 'odd' or 'even' depending on the number.
@@ -314,7 +414,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
 
 =head1 BUGS
 
